@@ -1,6 +1,6 @@
 package Data::Grid::Row;
 
-use 5.012;
+use 5.014;
 use strict;
 use warnings FATAL => 'all';
 
@@ -19,11 +19,11 @@ Data::Grid::Row - Row implementation for Data::Grid::Table
 
 =head1 VERSION
 
-Version 0.02_01
+Version 0.06
 
 =cut
 
-our $VERSION = '0.02_01';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -73,7 +73,7 @@ sub cells {
 =head2 width
 
 Returns the width of the row in columns. This is the same as C<scalar
-@{$row->cells}>.
+@{$row-E<gt>cells}>.
 
 =cut
 
